@@ -1,18 +1,20 @@
 package App::Bootstrap::Perl;
-# git description: v0.10-3-g424e8d3
-
 BEGIN {
   $App::Bootstrap::Perl::AUTHORITY = 'cpan:SCHWIGON';
 }
 # ABSTRACT: Bootstrap Perl inclusive CPAN from git
-$App::Bootstrap::Perl::VERSION = '0.11';
+$App::Bootstrap::Perl::VERSION = '0.12';
+use 5.006;
+use strict;
+use warnings;
+
 1;
 
 __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
